/**
 * 面交互效果绑定事件
 * 该方法最终会在request请求获得数据后执行
 */
function bindingAllEvent() {
    /*
     * 勾选事件
     * 状态:
     *   1. 勾选
     *   2. 取消勾选
     * 所有的勾选(或取消勾选)事件,最终都会调用商品勾选(或取消勾选)事件
     * 因此,除了商品勾选事件,其余勾选事件行为:1.改变样式 2.调用下一级事件
     * 最终的价格更改将会在也仅在单件商品点击时发生改变
     */
    //商品被勾选的事件
    var goodChoices = $('.good-choice');
    //勾选某件商品
    goodChoices.on('click', function () {
        //假如为not-choose,证明这次点击将变成is-choose,也就是选择购买
        if($(this).hasClass('fa-circle-o')) {//caixf
            $(this).trigger('good:fa-check-circle');//caixf
        } else if($(this).hasClass('fa-check-circle')) {//caixf
            $(this).trigger('good:fa-circle-o');//caixf
        }
    });
    //商品被勾选时执行的时间
    goodChoices.on('good:fa-check-circle', function() {//caixf
        //改变样式并标明该按钮被选中:not-choose或is-choose就代表boolean值
        if($(this).hasClass('fa-circle-o')) {//caixf
            $(this).removeClass('fa-circle-o').addClass('fa-check-circle');//caixf
            // 商店联动
            var chooseNum = 0;
            //当一家商店,商品有全部被点击的时候,将会更改商店被点击的样式
            var chooses = $(this).parent().parent().find('.good-choice');
            chooses.each(function(){
                return $(this).hasClass('fa-check-circle') ? chooseNum ++ :  false;//caixf
            });
            if (chooses.length == chooseNum) {
                $(this).parent().parent().find('.shop-choice').removeClass('fa-circle-o').addClass('fa-check-circle');//caixf
            }
            
            //但全部商品都被点击的时候,将会更改全选按钮的事件
            var chooses = $('.good-choice');
            var allChooseNum = 0;
            chooses.each(function(){
                return $(this).hasClass('fa-check-circle') ? allChooseNum ++ :  false;//caixf
            });
            if (chooses.length == allChooseNum) {
                $('#all-good-choice').removeClass('fa-circle-o').addClass('fa-check-circle');//caixf
            }
            
            //根据选中商品更改价格
            addSumPrice(calculateOneGoods($(this).parent()));
            //变更结算商品种类
            addSumNum();
        }
    });
    //商品被取消勾选的事件
    goodChoices.on('good:fa-circle-o', function() {//caixf
        if($(this).hasClass('fa-check-circle')) {//caixf
            $(this).removeClass('fa-check-circle').addClass('fa-circle-o');//caixf
            
            // 商店联动
            var chooses = $(this).parent().parent().find('.good-choice');
            var chooseNum = 0;
            chooses.each(function(){
                return $(this).hasClass('fa-check-circle') ? chooseNum ++ :  false;//caixf
            });
            if (chooses.length != chooseNum) {
                $(this).parent().parent().find('.shop-choice').removeClass('fa-check-circle').addClass('fa-circle-o');//caixf
            }
            
            //全选联动
            var allChooses = $('.good-choice');
            var allChooseNum = 0;
            allChooses.each(function(){
                return $(this).hasClass('fa-check-circle') ? allChooseNum++ :  false;//caixf
            });
            if (allChooses.length != allChooseNum) {
                $('#all-good-choice').removeClass('fa-check-circle').addClass('fa-circle-o');//caixf
            }
            
            //变更价格
            minusSumPrice(calculateOneGoods($(this).parent()));
            minusSumNum();
        }
    });

    var shopChoices = $('.shop-choice');
    //勾选某个商店
    shopChoices.on('click', function() {
        if($(this).hasClass('fa-circle-o')) {//caixf
            $(this).trigger('shop:fa-check-circle');//caixf
        } else {
            $(this).trigger('shop:fa-circle-o')//caixf
        }
    });
    //商店被勾选的事件,
    shopChoices.on('shop:fa-check-circle', function() {//caixf
        if($(this).hasClass('fa-circle-o')) {//caixf
            //选中该商品
            $(this).removeClass('fa-circle-o').addClass('fa-check-circle');//caixf
            //.parent().parent()代表  <div class="one-shop">...</div>
            //触发本商店中所有的商品的勾选时间
            $(this).parent().parent().find('.good-choice').trigger('good:ifa-check-circle');//caixf
        }
    });
    //商店被取消的事件
    shopChoices.on('shop:fa-circle-o', function() {//caixf
        if($(this).hasClass('fa-check-circle')) {//caixf
            //取消该商品
            $(this).removeClass('fa-check-circle');//caixf
            $(this).addClass('fa-circle-o');//caixf
            //触发本商品中所有的商品的取消事件
            $(this).parent().parent().find('.good-choice').trigger('good:fa-circle-o');//caixf
        }
    });

    //勾选全部时调用的事件
    $('#all-good-choice').on('click', function() {
        if($(this).hasClass('fa-circle-o')) {//caixf
            //选中该商品
            $(this).removeClass('fa-circle-o').addClass('fa-check-circle');//caixf
            $('.shop-choice').map(function() {
                //触发所有的商店勾选事件
                $(this).trigger('shop:fa-check-circle');//caixf
            });
        } else {
            //取消该商品
            $(this).removeClass('fa-check-circle').addClass('fa-circle-o');//caixf
            $('.shop-choice').map(function() {
                //触发所有的商店取消勾选事件
                $(this).trigger('shop:fa-circle-o');//caixf
            });
        }
    });

    /*
     * 编辑事件
     * 1.编辑数量
     * 2.删除该商品
     *
     * 当编辑数量和删除商品时,都执行请求后台的操作
     * 编辑(取消编辑)仅提供编辑数量和删除商品的界面,而不应执行其他操作
     * 也就是说,最终的实现在于增加数量或减少数量或删除按钮的点击,而不再编辑或取消编辑按钮的点击
     *
     */
    var shopEdits = $('.shop-edit');
    //编辑商店
    shopEdits.on('click', function() {
        if($(this).hasClass('is-edit')) {
            $(this).trigger('shop:not-edit');
        }else {
            $(this).trigger('shop:is-edit');
        }
    });
    //编辑单家商店商品
    shopEdits.on('shop:is-edit', function() {
        if($(this).hasClass('not-edit')) {
            $(this).removeClass('not-edit').addClass('is-edit');
            var aimDiv = $(this).parent().parent().children();
            aimDiv.children('.good-descript').hide();
            aimDiv.children('.good-price').hide();
            aimDiv.children('.good-num').show();
            aimDiv.children('.good-delete').show();
            $(this).text('完成');//caixf
        }
    });

    //取消商店商品编辑
    shopEdits.on('shop:not-edit', function() {
        if($(this).hasClass('is-edit')) {
            $(this).removeClass('is-edit');
            $(this).addClass('not-edit');
            var aimDiv = $(this).parent().parent().children();
            aimDiv.children('.good-descript').show();
            aimDiv.children('.good-price').show();
            aimDiv.children('.good-num').hide();
            aimDiv.children('.good-delete').hide();
            $(this).text('编辑');
        }
    });
    //编辑所有的商家
    $("#edit-all").on('click', function() {
        var aimElements = $('.shop-edit');
        if($(this).hasClass('is-edit')) {
            //取消编辑
            $(this).removeClass('is-edit').addClass('not-edit');
            aimElements.map(function() {
                $(this).trigger('shop:not-edit');
            });
            $(this).text('编辑全部');
        }else {
            //编辑
            $(this).removeClass('not-edit').addClass('is-edit');
            aimElements.map(function() {
                $(this).trigger('shop:is-edit');
            });
            $(this).text('完成');//caixf
        }
    });

//编辑具体按钮事件
    //点击减少商品数量
    $('.minus-num').on('click', function() {
        //改变输入框的数值
        var inputValue = $(this).next();
        var preValue = inputValue.attr('value');
        //获取原来的数量并进行-1操作
        var nowValue = parseInt(preValue) - 1;
        var _self = $(this);
        if(nowValue > 0) {
            updateCart($(this).parent().parent().attr('id'),nowValue,'minus-num',
                //请求服务器成功后对前台数据执行相应的修改
                function() {
                    $(inputValue.attr('value', nowValue));
                    //用改变后的数值取代原先的数值
                    //.parent().prev: <div class="good-price">...</div>
                    _self.parent().prev().find('.number').text(nowValue);
                    //计算所有货物的价格
                    calculateAllGoods();
                });
        }
    });
    //点击增加商品数量
    $('.add-num').on('click', function() {
        var inputValue = $(this).prev();
        var preValue = inputValue.attr('value');
        //获取原来的数值并进行+1操作
        var nowValue = parseInt(preValue) + 1;
        var _self = $(this);
        // 增加数量
        updateCart($(this).parent().parent().attr('id'),nowValue,'add-num',
            //请求服务器成功后对前台数据执行相应的修改
            function() {
                $(inputValue.attr('value', nowValue));
                _self.parent().prev().find('.number').text(nowValue);
                calculateAllGoods();
            });
    });
    //点击删除商品
    $('.good-delete').on('click', function() {
        //删除该商品
        var _self = $(this);
        deleteOneGoods($(this).parent().attr('id'), function() {
            var shopGoodsNum = _self.parent().parent().children('.good').length;
            if(shopGoodsNum <= 1) {
                //小于1,把整个店铺都删除
                _self.parent().parent().remove();
            }else {
                //删除单个商品
                _self.parent().remove();
            }
            //计算总价格
            calculateAllGoods();
        });
    });

    //点击结算按钮的相应事件,该方法只负责获得结算的商品id,具体的结算实现请参考confirmed_order.html
    $('#account').on('click', function(){
        var choiceGoods = [];
        //遍历所有的商品,是否被选中
        $('.good-choice').map(function() {
            if($(this).hasClass('fa-check-circle')) {//caixf
                choiceGoods.push($(this).parent().attr('id'));
            }
        });
        //假如没有选中商品,则不可跳转到支付页面
        if(choiceGoods.length===0) {
            return -1;
        }
        else {
            var formateIds = choiceGoods.join(',');
            //设置额外的操作
            appcan.locStorage.setVal('catInfoList', formateIds);
            //跳转到confirmed_order.html页面
            var hasAddr = appcan.locStorage.getVal('session_hasAddr');
            if (hasAddr == "1") {
                //clearHTMl();
                //saveHTML('index');
                //saveHTML('confirmed_order');
                appcan.window.open({
                    name:'confirmed_order',
                    dataType:0,
                    aniId:10,
                    data:'confirmed_order.html'
                });
            }else{
                appcan.openWinWithUrl('newaddress','newaddress.html');
            }
            //跳转到confirmed_order.html页面End
        }
    });
}
//ui中会被调用的其他方法
//合计价格增加价格
function addSumPrice(addPrice) {
    var sumMoney = $('#sum-money');
    var sum = parseFloat(sumMoney.text()) + parseFloat(addPrice);
    sumMoney.text(sum.toFixed(2));
}
//合计价格减少价格,参考addSumPrice
function minusSumPrice(minusPrice) {
    var sumMoney = $('#sum-money');
    var sum = parseFloat(sumMoney.text()) - parseFloat(minusPrice);
    sumMoney.text(sum.toFixed(2));
}
//增加商品种类,该方法指的是最后结算阶段"结算(number)"中的number
function addSumNum() {
    var sumNum = $('#account-goods-num');
    var num = parseInt(sumNum.text()) + 1;
    sumNum.text(num);
    if(num > 0) {
        ableToAccount();
    }
}
//减少商品种类,请参考addSumNum
function minusSumNum() {
    var sumNum = $('#account-goods-num');
    var num = parseInt(sumNum.text()) - 1;
    sumNum.text(num);
    if(num === 0) {
        unableToAccount();
    }
}
//允许结算
function ableToAccount() {
    $('#account').removeClass('unable-to-account').addClass('able-to-account');
}
//不允许结算
function unableToAccount() {
    $('#account').removeClass('able-to-account').addClass('unable-to-account');
}
//计算单件商品被选择的价格变化
function calculateOneGoods(domOfThis) {
    //计算价格
    var goodPrice = domOfThis.find('.good-price');
    var price = goodPrice.find('.price').text();
    var number = goodPrice.find('.number').text();
    return parseFloat(price) * parseInt(number);
}
//计算所有的价格
function calculateAllGoods() {
    //总计金额
    var totalPrice = 0.0;
    //所有商品
    var goods = $('.good');
    goods.map(function() {
        //假如被选中
        if($(this).find('.good-choice').hasClass('fa-check-circle')) { //caixf
            totalPrice += calculateOneGoods($(this));
        }
    });
    //
    if(isNaN(totalPrice)) totalPrice = 0;
    $('#sum-money').text(totalPrice.toFixed(2));
}

//和后台交互的请求
/**
 * 删除一件商品
 * @param id 商品id(该id代表的是该商品的数据库字段,eg:goods_3000_3000)
 * @param callback 但ajax请求成功后执行的回调函数,在本页面,一般为当且仅当后台执行成功后才改变前台数据
 */
function deleteOneGoods(id, callback){
    var param = {};
    //要删除的商品的id
    param['obj_ident'] = id;
    param['ctlname'] = 'cart_cart';
    param['method']='delete';
    param['login_name'] = appcan.locStorage.getVal('session_user');
    ajaxWrapperPost(param, callback);
}

// 更新货品数量,callback请参考deleteOneGoods
function updateCart(id, num, event, callback) {
    var username = appcan.locStorage.getVal('session_user');
    if (username == null || username == '') {
        pageJump('login.html');
    } else {
        if (id == null || id == '') {
            alert('此商品已下架');
            return;
        }
        var data = {};
        data['obj_ident'] = id;
        data['ctlname'] = 'details_addcart';
        data['method'] = 'updateCartProductNum';
        data['num'] = num;
        data['login_name'] = username;
        data['update_event'] = event;
        ajaxWrapperPost(data, callback);
    }
}

/**
 * 封装的AJAX请求
 * 1. 实现连接服务器时的loading画面
 * 2. 但连接超时的提示
 * @param data 传送的数据
 * @param successCall 成功时调用的方法
 * @param errorCall 失败时调用的方法
 * @constructor
 */
function ajaxWrapperPost(data, successCall, errorCall) {
    AJAX.post(data, function(json) {
        //一下一句判断是因为在请求删除产品时,json==true,而请求其他操作时,却返回json.stauts=true或json.status=false
        if(successCall && json.status) {
            successCall(json);   
        }else {
            appcan.window.openToast(json.msg, 2000, 5);
        }
    }, function() {
        appcan.window.openToast('请求数据失败', 2000, 5);
        if(errorCall) {
            errorCall();
        }
    }, 0);
}
